#!/usr/bin/env python
""" setup.py for Insect Navigation Toolbox
(called navipy)
"""
from setuptools import setup, find_packages

excluded = []


def exclude_package(pkg):
    for exclude in excluded:
        if pkg.startswith(exclude):
            return True
    return False


def create_package_list(base_package):
    return ([base_package] +
            [base_package + '.' + pkg
             for pkg
             in find_packages(base_package)
             if not exclude_package(pkg)])


setup_dict = {'name': 'navipy',
              'version': '0.1',
              'author': "Olivier J.N. Bertrand",
              'author_email': 'olivier.bertrand@uni-bielefeld.de',
              'description': 'Insect Navigation Toolbox',
              'packages': create_package_list("navipy"),
              'requires': ['numpy',
                           'pandas',
                           'matplotlib',
                           'scipy',
                           'networkx'],
              'install_requires': ["numpy",
                                   'pandas',
                                   'matplotlib',
                                   'scipy',
                                   'sphinx_rtd_theme',
                                   'networkx',
                                   'sphinx-argparse'],
              'package_data': {'navipy': ['resources/database.db',
                                          'resources/forest_world.blend']},
              'include_package_data': True,
              'entry_points': {
                  'console_scripts': [
                      'blendnavipy=navipy.sensors.blendnavipy:main']}, }

setup(**setup_dict)
